pub struct Authenticator { /* private fields */ }Implementations
Sourceimpl Authenticator
impl Authenticator
pub const ALPN: &'static [u8] = crate::ALPN
Sourcepub fn new<S: IntoSecret>(secret: S) -> Self
pub fn new<S: IntoSecret>(secret: S) -> Self
Examples found in repository?
examples/basic.rs (line 20)
18async fn main() -> Result<(), String> {
19 // 1. Create the authenticator with a shared secret
20 let auth = Authenticator::new("my-super-secret-password");
21
22 // 2. Build the endpoint with the auth hooks
23 let endpoint = Endpoint::builder(iroh::endpoint::presets::N0)
24 .hooks(auth.clone())
25 .bind()
26 .await.map_err(|e| e.to_string())?;
27
28 // 3. The authenticator needs a reference to the bound endpoint
29 // to initiate authentication handshakes.
30 auth.set_endpoint(&endpoint).await;
31
32 // 4. Register the auth protocol handler
33 let router = Router::builder(endpoint)
34 .accept(iroh_auth::ALPN, auth.clone())
35
36 // Register your actual application protocols here
37 .accept(b"/my-app/1.0", MyProtocolHandler)
38 .spawn();
39
40 // ... run your application
41 router.shutdown().await.map_err(|e| e.to_string())?;
42 Ok(())
43}Sourcepub async fn set_endpoint(&self, endpoint: &Endpoint)
pub async fn set_endpoint(&self, endpoint: &Endpoint)
Examples found in repository?
examples/basic.rs (line 30)
18async fn main() -> Result<(), String> {
19 // 1. Create the authenticator with a shared secret
20 let auth = Authenticator::new("my-super-secret-password");
21
22 // 2. Build the endpoint with the auth hooks
23 let endpoint = Endpoint::builder(iroh::endpoint::presets::N0)
24 .hooks(auth.clone())
25 .bind()
26 .await.map_err(|e| e.to_string())?;
27
28 // 3. The authenticator needs a reference to the bound endpoint
29 // to initiate authentication handshakes.
30 auth.set_endpoint(&endpoint).await;
31
32 // 4. Register the auth protocol handler
33 let router = Router::builder(endpoint)
34 .accept(iroh_auth::ALPN, auth.clone())
35
36 // Register your actual application protocols here
37 .accept(b"/my-app/1.0", MyProtocolHandler)
38 .spawn();
39
40 // ... run your application
41 router.shutdown().await.map_err(|e| e.to_string())?;
42 Ok(())
43}pub async fn is_authenticated(&self, id: &PublicKey) -> bool